PCB Environment: AStarVisitStatus Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
AStarVisitStatus Class Reference

`#include <NavPoint.hpp>`

## Public Member Functions
void | reset ()
void | setOpen (uint16_t seq)
void | setDone (uint16_t seq)
bool | isSeen (uint16_t seq) const
bool | isOpen (uint16_t seq) const
bool | isDone (uint16_t seq) const

## Detailed Description

This class is used to keep track of whether a NavPoint has been visited in the current invocation of A*. We use a sequence number so we don't have to reset all visited nodes each time (until the sequence wraps).

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavPoint.hpp